import unittest
from unittest.mock import Mock, patch

import symbl_rest
from symbl import AuthenticationToken
from symbl_rest import Configuration, ApiClient

from types import SimpleNamespace


class AuthenticationTokenTest(unittest.TestCase):

    def test_get_access_token_should_succeed_given_valid_token(self):
        demo_response = SimpleNamespace(**{"access_token":"eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6IlFVUTRNemhDUVVWQk1rTkJNemszUTBNMlFVVTRRekkyUmpWQ056VTJRelUxUTBVeE5EZzFNUSJ9.eyJodHRwczovL3BsYXRmb3JtLnN5bWJsLmFpL3VzZXJJZCI6IjYyOTg2MTI4NTIwNjQyNTYiLCJpc3MiOiJodHRwczovL2RpcmVjdC1wbGF0Zm9ybS5hdXRoMC5jb20vIiwic3ViIjoiWGNaYnA2MVk1dHJRVWEzVXhOZzkxc3MwSzdXRHN4UVdAY2xpZW50cyIsImF1ZCI6Imh0dHBzOi8vcGxhdGZvcm0ucmFtbWVyLmFpIiwiaWF0IjoxNjIyODA5NzU4LCJleHAiOjE2MjI4OTYxNTgsImF6cCI6IlhjWmJwNjFZNXRyUVVhM1V4Tmc5MXNzMEs3V0RzeFFXIiwiZ3R5IjoiY2xpZW50LWNyZWRlbnRpYWxzIn0.IXdme9NTdaiQFEUIgyfUtKPa8SYMXahcJ8mYRVi5gER4ntqqxeMoSBuIiZJNzwfOfsxZ-HO--azKsGokqJWtuZ3BMeW2OpucFyV1TGbbcYcXWrZwPSlMmcsfXMUlXGxCf7dnfmM48pUNTnpmS6jKpGyAPK4TCaHutSva0wWK93laB2c-ueM7UZ03u-onMkPMykg7_QqStx82ogaanSX-XUHNI7SuODy8strTIpW2DKzOgvg9S6PzDC3zvDyD-sdfXtYsByn8R94CxcGQ9kUs8AF_hOlwUdp_Apq2U57naoXPd3aQx4rRtPl52_2GU6CeGAK7IgI26WWCgcHAe3mLow","expires_in":76254})
        string_value = "demo_value"
        with patch("symbl_rest.AuthenticationApi.generate_token", Mock(return_value=demo_response)), patch("configparser.ConfigParser.get", Mock(return_value=string_value)):
            self.assertEqual(demo_response.access_token, AuthenticationToken.get_access_token())

    def test_get_api_header_should_succeed_given_valid_token(self):
        demo_response = SimpleNamespace(**{"access_token":"eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6IlFVUTRNemhDUVVWQk1rTkJNemszUTBNMlFVVTRRekkyUmpWQ056VTJRelUxUTBVeE5EZzFNUSJ9.eyJodHRwczovL3BsYXRmb3JtLnN5bWJsLmFpL3VzZXJJZCI6IjYyOTg2MTI4NTIwNjQyNTYiLCJpc3MiOiJodHRwczovL2RpcmVjdC1wbGF0Zm9ybS5hdXRoMC5jb20vIiwic3ViIjoiWGNaYnA2MVk1dHJRVWEzVXhOZzkxc3MwSzdXRHN4UVdAY2xpZW50cyIsImF1ZCI6Imh0dHBzOi8vcGxhdGZvcm0ucmFtbWVyLmFpIiwiaWF0IjoxNjIyODA5NzU4LCJleHAiOjE2MjI4OTYxNTgsImF6cCI6IlhjWmJwNjFZNXRyUVVhM1V4Tmc5MXNzMEs3V0RzeFFXIiwiZ3R5IjoiY2xpZW50LWNyZWRlbnRpYWxzIn0.IXdme9NTdaiQFEUIgyfUtKPa8SYMXahcJ8mYRVi5gER4ntqqxeMoSBuIiZJNzwfOfsxZ-HO--azKsGokqJWtuZ3BMeW2OpucFyV1TGbbcYcXWrZwPSlMmcsfXMUlXGxCf7dnfmM48pUNTnpmS6jKpGyAPK4TCaHutSva0wWK93laB2c-ueM7UZ03u-onMkPMykg7_QqStx82ogaanSX-XUHNI7SuODy8strTIpW2DKzOgvg9S6PzDC3zvDyD-sdfXtYsByn8R94CxcGQ9kUs8AF_hOlwUdp_Apq2U57naoXPd3aQx4rRtPl52_2GU6CeGAK7IgI26WWCgcHAe3mLow","expires_in":76254})
        string_value = "demo_value"
        with patch("symbl_rest.AuthenticationApi.generate_token", Mock(return_value=demo_response)), patch("configparser.ConfigParser.get", Mock(return_value=string_value)):
            self.assertEqual({'x-api-key': demo_response.access_token}, AuthenticationToken.get_api_header())

    def test_get_api_client_should_succeed_given_valid_token(self):
        demo_response = SimpleNamespace(**{"access_token":"eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCIsImtpZCI6IlFVUTRNemhDUVVWQk1rTkJNemszUTBNMlFVVTRRekkyUmpWQ056VTJRelUxUTBVeE5EZzFNUSJ9.eyJodHRwczovL3BsYXRmb3JtLnN5bWJsLmFpL3VzZXJJZCI6IjYyOTg2MTI4NTIwNjQyNTYiLCJpc3MiOiJodHRwczovL2RpcmVjdC1wbGF0Zm9ybS5hdXRoMC5jb20vIiwic3ViIjoiWGNaYnA2MVk1dHJRVWEzVXhOZzkxc3MwSzdXRHN4UVdAY2xpZW50cyIsImF1ZCI6Imh0dHBzOi8vcGxhdGZvcm0ucmFtbWVyLmFpIiwiaWF0IjoxNjIyODA5NzU4LCJleHAiOjE2MjI4OTYxNTgsImF6cCI6IlhjWmJwNjFZNXRyUVVhM1V4Tmc5MXNzMEs3V0RzeFFXIiwiZ3R5IjoiY2xpZW50LWNyZWRlbnRpYWxzIn0.IXdme9NTdaiQFEUIgyfUtKPa8SYMXahcJ8mYRVi5gER4ntqqxeMoSBuIiZJNzwfOfsxZ-HO--azKsGokqJWtuZ3BMeW2OpucFyV1TGbbcYcXWrZwPSlMmcsfXMUlXGxCf7dnfmM48pUNTnpmS6jKpGyAPK4TCaHutSva0wWK93laB2c-ueM7UZ03u-onMkPMykg7_QqStx82ogaanSX-XUHNI7SuODy8strTIpW2DKzOgvg9S6PzDC3zvDyD-sdfXtYsByn8R94CxcGQ9kUs8AF_hOlwUdp_Apq2U57naoXPd3aQx4rRtPl52_2GU6CeGAK7IgI26WWCgcHAe3mLow","expires_in":76254})
        string_value = "demo_value"
        configuration_instance = Configuration()
        configuration_instance.api_key['x-api-key'] = demo_response.access_token
        with patch("symbl_rest.AuthenticationApi.generate_token", Mock(return_value=demo_response)), patch("configparser.ConfigParser.get", Mock(return_value=string_value)):
            returnValue = AuthenticationToken.get_api_client()
            self.assertIsNotNone(returnValue)
            self.assertIsInstance(returnValue, symbl_rest.ApiClient)
            self.assertEqual(returnValue.configuration.api_key, configuration_instance.api_key)

if __name__ == '__main__':
    unittest.main()



from symbl import StreamingConnection
from symbl.configs.configs import SYMBL_STREAMING_API_FORMAT
from symbl.AuthenticationToken import get_access_token
import websocket
import base64
import random
import string

class StreamingApi():
    def __init__(self):
        '''
            It will initialize the ConversationsApi class
        '''
        pass


    def start_connection(self, credentials=None, speaker=None, insight_types=None, configs={}):
        randomId = bytes(''.join(random.choices(string.ascii_uppercase +string.digits, k=12)), 'utf-8')
        id = base64.b64encode(randomId).decode("utf-8")
        url = SYMBL_STREAMING_API_FORMAT.format(id, get_access_token(credentials=credentials))

        start_request = {
            "type": "start_request",
            "insightTypes": [] if insight_types == None else [] if type(insight_types) != list else insight_types,
            "speaker": speaker,
             "config": configs if configs != {} and configs != None else {
                "confidenceThreshold": 0.5,
                "languageCode": 'en-US',
                "speechRecognition": {
                    "encoding": 'LINEAR16',
                    "sampleRateHertz": 44100,
                }
            },
        }
    
        return StreamingConnection(url= url, connectionId=id, start_request=start_request)

    def stop_listening(self, url: str):
        connection = websocket.WebSocketApp(url=url)
        stop_payload = {'type': 'stop_request'}
        connection.send(str(stop_payload))


def correct_boolean_values(dictionary: dict):
    for key in dictionary:
        if dictionary[key] == True and type(dictionary[key]) == bool:
            dictionary[key] = "true"
        elif dictionary[key] == False and type(dictionary[key]) == bool:
            dictionary[key] = "false"
    return dictionary

def change_camel_case_to_snake_case(dictionary: dict):
    new_dictionary = dict()
    for key in dictionary.keys():
        new_key = ''.join(['_'+i.lower() if i.isupper() else i for i in key]).lstrip('_')
        new_dictionary[new_key] = dictionary[key]
    
    return new_dictionary


import threading

class Thread():

    __instance = None
    threads = []

    @staticmethod
    def getInstance():
        if Thread.__instance == None:
            return Thread()
        
        return Thread.__instance
    
    def __init__(self):
        if Thread.__instance != None:
            raise Exception("Can not instantiate more than once!")
        else:
            Thread.__instance = self
        

    def start_on_thread(self, target, *args):
        thread = threading.Thread(target=target, args=(*args,))
        self.threads.append(thread)
        thread.start()

    def stop_all_threads(self):
        for thread in self.threads:
            thread.join()



from symbl.telephony_api.TelephonyApi import TelephonyApi
import unittest
from unittest.mock import Mock, patch

from types import SimpleNamespace


class TelephonyTest(unittest.TestCase):

    def test_start_pstn_should_succeed_given_valid_phone(self):
        demo_response = SimpleNamespace(**{"event_url":"https://api.symbl.ai/v1/event/7025ecfa-a050-40aa-aa2d-0628b6d097b5","result_web_socket_url":"wss://api.symbl.ai/events/7025ecfa-a050-40aa-aa2d-0628b6d097b5","conversation_id":"5219424513556480","connection_id":"7025ecfa-a050-40aa-aa2d-0628b6d097b5"})
        demo_actions = [{"invokeOn": "stop", "name": "sendSummaryEmail", "parameters": { "emails": [ "example@example.com"  ]}}]
        telephony_class = TelephonyApi()

        with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")), patch("symbl_rest.ConnectionToEndpointApi.connect_to_endpoint", Mock(return_value=demo_response)):
            self.assertEqual(demo_response.conversation_id, telephony_class.start_pstn('demophone', actions=demo_actions).conversation.get_conversation_id())

    def test_start_sip_should_succeed_given_valid_sip(self):
        demo_response = SimpleNamespace(**{"event_url":"https://api.symbl.ai/v1/event/7025ecfa-a050-40aa-aa2d-0628b6d097b5","result_web_socket_url":"wss://api.symbl.ai/events/7025ecfa-a050-40aa-aa2d-0628b6d097b5","conversation_id":"5219424513556480","connection_id":"7025ecfa-a050-40aa-aa2d-0628b6d097b5"})
        telephony_class = TelephonyApi()

        with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")), patch("symbl_rest.ConnectionToEndpointApi.connect_to_endpoint", Mock(return_value=demo_response)):
            self.assertEqual(demo_response.conversation_id, telephony_class.start_sip('demophone').conversation.get_conversation_id())

    # def test_start_sip_should_succeed_given_valid_sip(self):
    #     demo_response = SimpleNamespace(**{"event_url":"https://api.symbl.ai/v1/event/7025ecfa-a050-40aa-aa2d-0628b6d097b5","result_web_socket_url":"wss://api.symbl.ai/events/7025ecfa-a050-40aa-aa2d-0628b6d097b5","conversation_id":"5219424513556480","connection_id":"7025ecfa-a050-40aa-aa2d-0628b6d097b5"})
    #     telephony_class = TelephonyApi()

    #     with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")), patch("symbl_rest.ConnectionToEndpointApi.connect_to_endpoint", Mock(return_value=demo_response)):
    #         self.assertEqual(demo_response.connection_id, telephony_class.stop('demophone'))

if __name__ == '__main__':
    unittest.main()



from unittest import mock

from symbl.async_api.Audio import Audio, correct_boolean_values
import unittest
from unittest.mock import Mock, patch

from types import SimpleNamespace


class AudioTest(unittest.TestCase):

    def test_correct_boolean_values(self):
        test_dict = {'a': True, 'b': 'true', 'c': 'hello'}
        expected_dict = {'a': 'true', 'b': 'true', 'c': 'hello'}
        self.assertDictEqual(correct_boolean_values(test_dict), expected_dict)

    def test_process_file_should_fail_if_no_file_path(self):
        audio_class = Audio()
        with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")):
            self.assertRaises(TypeError, audio_class.process_file)
            self.assertRaises(ValueError, audio_class.process_file, None)

    def test_process_file_should_succeed_given_valid_path(self):
        demo_response = SimpleNamespace(
            **{"job_id": "demo job id", "conversation_id": "conversationId"})
        demo_job_response = SimpleNamespace(
            **{"job_id": "demo job id", "status": "completed"})
        mock_open = mock.mock_open(read_data=bytes([1, 2, 3, 4, 5, 6, 7, 8]))
        audio_class = Audio()

        with patch('builtins.open', mock_open), patch("symbl.AuthenticationToken.get_api_client",
                                                      Mock(return_value="None")), patch("symbl_rest.AsyncApi.add_audio",
                                                                                        Mock(return_value=demo_response)), patch(
                "symbl_rest.JobsApi.get_job_status", Mock(return_value=demo_job_response)), patch(
                "time.sleep", Mock(return_value=None)
        ):
            self.assertEqual(demo_response.conversation_id, audio_class.process_file(
                'abcd').get_conversation_id())

    def test_process_url_should_succeed_given_valid_url(self):
        demo_response = SimpleNamespace(
            **{"job_id": "demo job id", "conversation_id": "conversationId"})
        demo_job_response = SimpleNamespace(
            **{"job_id": "demo job id", "status": "completed"})
        audio_class = Audio()

        with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")), patch(
                "symbl_rest.AsyncApi.add_audio_url", Mock(return_value=demo_response)), patch(
                "symbl_rest.JobsApi.get_job_status", Mock(return_value=demo_job_response)), patch(
                "time.sleep", Mock(return_value=None)
        ):
            self.assertEqual(demo_response.conversation_id, audio_class.process_url(
                'abcd').get_conversation_id())

    def test_append_file_should_succeed_given_valid_path(self):
        demo_response = SimpleNamespace(
            **{"job_id": "demo job id", "conversation_id": "conversationId"})
        demo_job_response = SimpleNamespace(
            **{"job_id": "demo job id", "status": "completed"})
        mock_open = mock.mock_open(read_data=bytes([1, 2, 3, 4, 5, 6, 7, 8]))
        audio_class = Audio()

        with patch('builtins.open', mock_open), patch("symbl.AuthenticationToken.get_api_client",
                                                      Mock(return_value="None")), patch(
                "symbl_rest.AsyncApi.append_audio", Mock(return_value=demo_response)), patch(
                "symbl_rest.JobsApi.get_job_status", Mock(return_value=demo_job_response)), patch(
                "time.sleep", Mock(return_value=None)
        ):
            self.assertEqual(demo_response.conversation_id,
                             audio_class.append_file('abcd', 'conversationId').get_conversation_id())

    def test_append_url_should_succeed_given_valid_url(self):
        demo_response = SimpleNamespace(
            **{"job_id": "demo job id", "conversation_id": "conversationId"})
        demo_job_response = SimpleNamespace(
            **{"job_id": "demo job id", "status": "completed"})
        audio_class = Audio()

        with patch("symbl.AuthenticationToken.get_api_client", Mock(return_value="None")), patch(
                "symbl_rest.AsyncApi.append_audio_url", Mock(return_value=demo_response)), patch(
                "symbl_rest.JobsApi.get_job_status", Mock(return_value=demo_job_response)), patch(
                "time.sleep", Mock(return_value=None)
        ):
            self.assertEqual(demo_response.conversation_id,
                             audio_class.append_url('abcd', 'conversationId').get_conversation_id())


if __name__ == '__main__':
    unittest.main()



from symbl.jobs_api.Job import Job
from symbl.jobs_api.JobStatus import JobStatus
from symbl.conversations_api.ConversationsApi import ConversationsApi

class Conversation():

    __INTERVAL_TIME_IN_SECONDS = 30  ## in seconds

    def __init__(self, conversationId: str, jobId: str=None,  wait=True, credentials=None):
        
        self.__conversation_id = conversationId
        self.__wait = wait
        self.__credentials = credentials
        self.__conversation_api = ConversationsApi()

        if jobId != None:
            self.__job = Job(conversation_id=conversationId, job_id=jobId, wait=wait)
            self.__monitorJob()
    
    def get_conversation_id(self):
        return self.__conversation_id
    
    def get_job_status(self):
        return self.__job.__job_status.value

    def on_complete(self, func):
        self.__job.on_complete(func)
        return self

    def on_error(self, func):
        self.__job.on_error(func)
        return self

    def action_items(self):
        return self.__conversation_api.get_action_items(self.__conversation_id, credentials=self.__credentials)

    def follow_ups(self):
        return self.__conversation_api.get_follow_ups(self.__conversation_id, credentials=self.__credentials)

    def insights(self):
        return self.__conversation_api.get_insights(self.__conversation_id, credentials=self.__credentials)
  
    def members(self):  
        return self.__conversation_api.get_members(self.__conversation_id, credentials=self.__credentials)
  
    def messages(self, parameters={}):  
        return self.__conversation_api.get_messages(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
  
    def questions(self):  
        return self.__conversation_api.get_questions(self.__conversation_id, credentials=self.__credentials)
  
    def topics(self, parameters={}):  
        return self.__conversation_api.get_topics(self.__conversation_id, credentials=self.__credentials, parameters=parameters)
        
    def __monitorJob(self):
        self.__job.monitor_job(self, interval=self.__INTERVAL_TIME_IN_SECONDS, wait=self.__wait, credentials=self.__credentials)